/* ---------------------------------------------------------------------------
created on: 01.04.2007
    by: GoerntKai

Copyright: (c) 2007 by Kai Grnt (kai.goernt@dimensionswandler.de).
All rights reserved.
--------------------------------------------------------------------------- */

package de.goerntkai.toolbox.cmdln;

/**
 * <p>Represents a command line as given by the user to start the
 * application.</p>
 *
 * <p>The commando itself is the first thing entered in the command line. It is
 * followed by options and arguments.</p>
 *
 * @author <a href="kai.goernt@dimensionswandler.de">Kai Grnt</a>
 * @version $Id: CommandLine.java,v 1.9 2007/05/01 17:08:22 GoerntKai Exp $
 */
public interface CommandLine {

    /**
     * <p>Returns the commando.</p>
     *
     * <dl>
     *  <dt>Postconditions</dt>
     *  <dd>result != <code>null</code></dd>
     * </dl>
     *
     * @return the commando
     */
    String getCommando();

    /**
     * <p>Returns the text of the help document. In case of an invalid command
     * line the help text should begin with the command line followed by the
     * mistakes.</p>
     *
     * <dl>
     *  <dt>Postconditions</dt>
     *  <dd>result != <code>null</code></dd>
     * </dl>
     *
     * @return the text of the help document
     */
    String[] getHelpText();

    /**
     * <p>Returns the command line parameter with the given name.</p>
     *
     * <dl>
     * <dt>Preconditions</dt>
     * <dd>theName != <code>null</code></dd>
     *
     * <dt>Postconditions</dt>
     * <dd>result != <code>null</code></dd>
     * </dl>
     *
     * @param theName of the command line parameter to get
     * @return the command line parameter
     */
    CommandLineParameter getParameter(String theName);

    /**
     * <p>Returns <code>true</code> when the given command line was valid,
     * <code>false</code> otherwise.</p>
     *
     * @return wether the command line is valid
     */
    boolean isValid();
}



/* end of file ------------------------------------------------------------ */
