/* ---------------------------------------------------------------------------
created on: 29.04.2005
    by: GoerntKai

Copyright: (c) 2005 by Kai Grnt (kai.goernt@dimensionswandler.de).
All rights reserved.
--------------------------------------------------------------------------- */

package de.goerntkai.toolbox.log;

import java.util.logging.Formatter;
import java.util.logging.LogRecord;

/**
 * <p>The <code>ConsoleFormatter</code> displays only the messages. As there
 * are no disturbing informations it will be a good choice when the task is
 * only to inform the user of what's going on.</p>
 *
 * @author <a href="kai.goernt@dimensionswandler.de">Kai Grnt</a>
 * @version $Id: ConsoleFormatter.java,v 1.3 2007/04/29 17:54:03 GoerntKai Exp $
 */
public class ConsoleFormatter extends Formatter {

    /**
     * <p>Standard Constructor.</p>
     */
    public ConsoleFormatter() {

        super();
    }

    /**
     * <p>Formats the log output.</p>
     *
     * @param theRecord to format
     * @return the log output as a single line
     * @see java.util.logging.Formatter#format(java.util.logging.LogRecord)
     */
    public final synchronized String format(final LogRecord theRecord) {

        StringBuffer output = new StringBuffer();

        // adds message
        output.append(theRecord.getMessage());

        // adds Throwable
        Throwable exception = theRecord.getThrown();
        if (exception != null) {
            output.append(" - "); //$NON-NLS-1$
            output.append(exception);
        }

        // not added:
        //record.getSequenceNumber();
        //record.getLoggerName();
        //record.getThreadID();
        //record.getMillis();
        //record.getSourceClassName();
        //record.getSourceMethodName();
        //record.getLevel();
        //record.getParameters();
        //record.getResourceBundle();

        // adds new line
        output.append("\n"); //$NON-NLS-1$

        return output.toString();

    }

}



/* end of file ------------------------------------------------------------ */
