/* ---------------------------------------------------------------------------
created on: 31.03.2007
    by: GoerntKai

Copyright: (c) 2007 by Kai Grnt (kai.goernt@dimensionswandler.de).
All rights reserved.
--------------------------------------------------------------------------- */

package de.goerntkai.toolbox.misc;

/**
 * <p>Provides some tasks for dealing with <code>String</code>s.</p>
 *
 * @author <a href="kai.goernt@dimensionswandler.de">Kai Grnt</a>
 * @version $Id: StringUtil.java,v 1.3 2007/05/01 14:53:42 GoerntKai Exp $
 */
public abstract class StringUtil {

    /**
     * <p>Suppresses external instantiation.</p>
     */
    private StringUtil() {

        // nop
    }

    /**
     * <p>Adds leading characters to a given String. If the string is already
     * longer than the given length it will be cut down to it. If the string
     * is <code>null</code> the returned string will only consist of the given
     * characters.</p>
     *
     * @param theCharacter to enlengthen the string with
     * @param theString to enlengthen
     * @param theLength to enlengthen the string to
     * @return the string with leading characters up to the given length
     */
    public static String leadWithCharacter(
        final char theCharacter,
        final String theString,
        final int theLength
    ) {

        StringBuffer buffer = null;
        if (theString == null) {
            buffer = new StringBuffer();
        } else {
            buffer = new StringBuffer(theString);
        }

        while (buffer.length() < theLength) {
            buffer.insert(0, theCharacter);
        }

        return buffer.substring(buffer.length() - theLength);
    }

    /**
     * <p>Adds leading spaces to a given String. If the string is already
     * longer than the given length it will be cut down to it. If the string
     * is <code>null</code> the returned string will only consist of
     * spaces.</p>
     *
     * @param theString to enlengthen
     * @param theLength to enlengthen the string to
     * @return the string with leading spaces up to the given length
     */
    public static String leadWithSpaces(
        final String theString,
        final int theLength
    ) {

        return leadWithCharacter(' ', theString, theLength);
    }

    /**
     * <p>Adds leading zeroes to a given integer. If the integer is already
     * longer than the given length it will be cut down to it. If the integer
     * is <code>null</code> the returned string will only consist of
     * zeroes.</p>
     *
     * @param theString to enlengthen
     * @param theLength to enlengthen the string to
     * @return the string with leading zeroes up to the given length
     */
    public static String leadWithZeroes(
        final int theString,
        final int theLength
    ) {

        return leadWithCharacter('0', String.valueOf(theString), theLength);
    }

    /**
     * <p>Adds leading zeroes to a given String. If the string is already
     * longer than the given length it will be cut down to it. If the string
     * is <code>null</code> the returned string will only consist of
     * zeroes.</p>
     *
     * @param theString to enlengthen
     * @param theLength to enlengthen the string to
     * @return the string with leading zeroes up to the given length
     */
    public static String leadWithZeroes(
        final String theString,
        final int theLength
    ) {

        return leadWithCharacter('0', theString, theLength);
    }
}



/* end of file ------------------------------------------------------------ */
