/* ---------------------------------------------------------------------------
created on: 31.03.2007
    by: GoerntKai

Copyright: (c) 2007 by Kai Grnt (kai.goernt@dimensionswandler.de).
All rights reserved.
--------------------------------------------------------------------------- */

package de.goerntkai.toolbox.time;

/**
 * <p>Measures elapsed time.</p>
 *
 * <p>The moment <code>Clock</code> is instantiated it beginns counting.
 * Every time <code>getElapsedMillis</code> is called it returns the time
 * elapsed since instantiation in milliseconds. The clock does not stop
 * counting so any subsequent call of <code>getElapsedMillis</code> returns
 * the time elapsed since instantiation. If the start of a new counting is
 * needed <code>reset</code> has to be called.</p>
 *
 * @author <a href="kai.goernt@dimensionswandler.de">Kai Grnt</a>
 * @version $Id: Clock.java,v 1.2 2007/04/29 17:54:04 GoerntKai Exp $
 */
public interface Clock {

    /**
     * <p>Returns the elapsed time in milliseconds since the instantiation or
     * the last <code>reset()</code>.</p>
     *
     * @return elapsed milliseconds
     */
    long getElapsedMillis();

    /**
     * <p>Resets the starting time.</p>
     */
    void reset();

}

/* end of file ------------------------------------------------------------ */
